/* 
	https://de.wikipedia.org/wiki/Schneepflug
	https://en.wikipedia.org/wiki/SnowPlough (or SnowPlow (AE))

	Schildträger, also das Ding, an dem der Schild befestigt wird - von Drehachse bis Car-Chassis

History: v5 bekommt einen längeres Gelenk (das zum hochschwenken)
			Löcher in Zapfen vergrössert.

ToDo:

		- Platte dicker machen, damit die 7.5er Löcher um 0.5 vergr. werden können

*/

/* Modules */
include <../Modules/Module_Geometrical_Objects.scad>;

/* Globals */
$fn=90;
gMS=8.0;
gSchildDia=75;
//gSchildTraegerSeitenLaenge1=80;
//gSchildTraegerSeitenLaenge2=gSchildDia*1.0;
gScrewHoleDia=4.3; // fitting M4
gScrewHoleDiaNoNut=3.6; // fitting M4, when not using nut 
//gSchildTraegerVerbinderLaenge=100;
//gSchildTraegerDurchmesser=32;
//gSchildTraegerLaenge=40;
gSchildTraegerBreite=50;
//gSchildTraegerVerbinderSlotWidth=4.2-0.2;
//gSchildTraegerVerbinderSlotHeight=2.0;
gGelenkDepth=10;
gSpace=0.4;
gLeverHeight=23;
gServoTraegerBreite=gSchildTraegerBreite;
gServoTraegerLaenge=55;
gServoHalterHoehe=20;
gServoHalterBreite=7.5-0.5;
gChassisVerbinderLaenge=23;
gChassisVerbinderBreite=gServoTraegerBreite;
gChassisVerbinderTubeDia=7.5-0.5;
gChassisVerbinderTubeLen=23*2;
gChassisVerbinderHoleDia=1.5+0.5+0.6;

if (1)
{
	if (1)
	servoTraeger1();
	
	if (1)
	translate([-30, 0, 0])
	verbindungsZapfen();
}

// Der Servoträger und x-Drehgelenk für Schild-Anhebung
module servoTraeger1()
{
	/* Gelenk */
	gy=gMS; //gGelenkDepth-gSpace*2;
	gx=gSchildTraegerBreite-gMS-gMS+0*gSpace;
	
	//	translate([-gMS/2, 0, gMS/2])
	translate([-gy/2, 0, gy/2])
	difference()
	{
		hull()
		{
			translate([-(gGelenkDepth-gMS)-3, 0, 0])
			rotate([90, 0, 0])
			cylinder(d=gy, h=gx, center=true);
			
			translate([gy/2-1/2, 0, 0])
			cube([1, gx, gy],center=true);
		} // hull
		
		translate([-(gGelenkDepth-gMS)-3, 0, 0])
		rotate([90, 0, 0])
		cylinder(d=gScrewHoleDiaNoNut, h=gx, center=true);
	} // diff
	
	/* Servoträger und Chassisverbinder */
	translate([gServoTraegerLaenge/2, 0, gMS/2])
	cube([gServoTraegerLaenge, gServoTraegerBreite, gMS], center=true);
	
	/* Servohalter */
	for (xi=[0, gServoTraegerLaenge-gServoHalterBreite])
	translate([xi, -15, 0])
	difference()
	{
		translate([0+gServoHalterBreite/2, gServoTraegerBreite/2-gMS/2, gMS+gServoHalterHoehe/2])
		cube([gServoHalterBreite, gMS, gServoHalterHoehe], center=true);
	
		for (hi=[5,15])
		{
			translate([gServoHalterBreite/2+0, gServoTraegerBreite/2-gMS/2, gMS+hi])
			rotate([90, 0, 0])
			cylinder(d=gScrewHoleDiaNoNut, h=gMS, center=true);
		}
	}
	
	/* Chassis-Verbinder */
	difference()
	{
		//union()
		//{
		translate([gServoTraegerLaenge, 0, 0])
		translate([gChassisVerbinderLaenge/2, 0, gMS/2])
		cube([gChassisVerbinderLaenge, gChassisVerbinderBreite, gMS], center=true);
		
		for(yi=[40/2,-40/2])
		{
			//{
				translate([(gServoTraegerLaenge+gChassisVerbinderLaenge)*1-gChassisVerbinderTubeLen/2/2, yi, gMS/2+0*gChassisVerbinderTubeDia/2])
				rotate([0, 90, 0])
				cylinder(d=gChassisVerbinderTubeDia+gSpace*1, h=gChassisVerbinderTubeLen/2, center=true);
				
				translate([gServoTraegerLaenge+gChassisVerbinderLaenge-8, yi, 0])
				cylinder(d=gChassisVerbinderHoleDia, h=23, center=true);
			
		} // for
		} // diff
		//}
		
	//}
	
/*gServoTraegerBreite=gSchildTraegerBreite;
gServoTraegerLaenge=55;
	=30;
	=gServoTraegerBreite;*/


} // module servoTraeger1

module verbindungsZapfen()
{
	for(yi=[40/2,-40/2])
	{
		difference()
		{
			translate([0, yi, gChassisVerbinderTubeLen/2])
			//srotate([0, 90, 0])
			cylinder(d=gChassisVerbinderTubeDia, h=gChassisVerbinderTubeLen, center=true);
			
			for(xi=[gChassisVerbinderHoleDia*1.5:4:gChassisVerbinderTubeLen-gChassisVerbinderHoleDia])
			translate([0, yi, xi])
			rotate([0, 90, 0])
			cylinder(d=gChassisVerbinderHoleDia, h=23, center=true);

		} // diff
	} // for

}

















